=============
Flask-LwAdmin
=============

Flask Lightningwolf Admin
-------------------------

LwAdmin is a set of macros, classes, and methods to assist in the creation of administrative panels based on the
bootstrap framework. At the moment we are working on the main section of the navigation and basic helpers for CRUD model.

The main assumptions of LwAdmin is not to restrict the coder. LwAdmin it is not a complete utility to be run
as it is `Flask-Admin <https://github.com/mrjoes/flask-admin/>`_

If you are just thinking about the basic CRUD scheme should rather think of using `Flask-Admin <https://github.com/mrjoes/flask-admin/>`_.
This plugin is to be useful only when you need a custom administration panel - creating new pages requires that in this case more work to gain same effect.

At the moment we use a bootstrap version 2.3.x, but in the near future will be updated to version 3.0.x.
We are waiting for jQuery UI Bootstrap (v1.0) to have both Flask-Bootsrap and Flask-JqueryUiBootstrap in this version.

Versioning
++++++++++

The project uses the `Semantic Versioning 2.0.0 <http://semver.org/>`_. Work is currently underway,
but because Flask-LwAdmin is already being used in production enviroment then API changes occur only in case of change parameter **y** in (**0.y.z**)

Examples
++++++++

Check SAMPLE_PROJECT for basic use example. More advanced use in this moment can be check in:
`Lightningwolf Smp Project <https://git.thunderwolf.net/lightningwolf/lightningwolf-smp>`_

Documentation
+++++++++++++

The documentation will be created in the near future. We know how important good documentation is for the proper development of the project.

How you can help
----------------

Comments
++++++++

We like comments.


Bug reports
+++++++++++

If you want to help us out, please file a bug report on our tracker at:

  `Github Flask-LwAdmin Issues <https://github.com/lightningwolf/Flask-LwAdmin/issues>`_

Please be as descriptive as possible and tell us what exactly you were doing
at the time something went wrong. If possible, send us a exception backtrace and if possible
example code.


Wishes
++++++

We can't possibly know what everyone wants, so we appreciate all feature
requests. These can be submitted to the issue tracker as well (see above).

**Any opinion and ideas are welcome.**


Programming
+++++++++++

Patches are welcome.

